@@ -36,25 +36,21 @@ impl Jest {
                 Ok(stmt) => match &stmt {
                     Stmt::Expr(ExprStmt { expr, .. }) => match &**expr {
                         Expr::Call(CallExpr {
-                            callee: ExprOrSuper::Expr(callee),
+                            callee: Callee::Expr(callee),
                             ..
                         }) => match &**callee {
                             Expr::Member(
                                 callee @ MemberExpr {
-                                    computed: false, ..
-                                },
-                            ) => match &callee.obj {
-                                ExprOrSuper::Super(_) => new.push(T::from_stmt(stmt)),
-                                ExprOrSuper::Expr(callee_obj) => match &**callee_obj {
-                                    Expr::Ident(i) if i.sym == *"jest" => match &*callee.prop {
-                                        Expr::Ident(prop) if HOIST_METHODS.contains(&*prop.sym) => {
-                                            hoisted.push(T::from_stmt(stmt));
-                                            return;
-                                        }
-                                        _ => new.push(T::from_stmt(stmt)),
-                                    },
-                                    _ => new.push(T::from_stmt(stmt)),
+                                    prop: MemberProp::Ident(prop),
+                                    ..
                                 },
+                            ) => match &*callee.obj {
+                                Expr::Ident(i)
+                                    if i.sym == *"jest" && HOIST_METHODS.contains(&*prop.sym) =>
+                                {
+                                    hoisted.push(T::from_stmt(stmt))
+                                }
+                                _ => new.push(T::from_stmt(stmt)),
                             },
                             _ => new.push(T::from_stmt(stmt)),
                         },
